---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. server command
2. client command
3. specific action to trigger the bug

**System Information (please complete the following information):**
 - Server OS: [e.g. RHEL 8.x]
 - Client OS: [e.g. Windows 10]
 - Xpra Server Version [e.g. 4.2.3]
 - Xpra Client Version [e.g. 4.3]

**Additional context**
Add any other context about the problem here.
Please see "reporting bugs" in the wiki section.
